@@ -44,6 +44,29 @@ for bar in bar_series:
     print("["+instrument_id_b+"]"+str(index)+":"+bar.to_string())
     index += 1
 
+
+begin_trading_date = datetime.datetime(2019, 5, 1)
+end_trading_date = datetime.datetime(2019, 5, 8)
+instrument_id = "IF9999"
+interval = 5
+bar_type = EnumBarType.minute
+bar_series = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, interval, bar_type, begin_trading_date, end_trading_date)
+index = 1
+for bar in bar_series:
+    print("["+instrument_id+"]"+str(index)+":"+bar.to_string())
+    index += 1
+
+length = 20
+end_trading_date = datetime.datetime(2019, 5, 8)
+instrument_id = "IF9999"
+interval = 5
+bar_type = EnumBarType.minute
+bar_series = qi_data_controller.load_bar_series_by_length(EnumMarket.期货, instrument_id, interval, bar_type, length, end_trading_date)
+index = 1
+for bar in bar_series:
+    print("["+instrument_id+"]"+str(index)+":"+bar.to_string())
+    index += 1
+
 # lst_a = []
 # for bar in bar_series:
 #     lst_a.append([bar.trading_date, bar.begin_time, bar.end_time, bar.open, bar.high, bar.low, bar.close, bar.pre_close, bar.volume])
